﻿Public Class ClsCh_Froid
    Dim x_θint, x_Hrbas, x_Hrhaut, x_GCheure, x_VentRatio, x_VentPu, x_PersoTU, x_PersoPu, x_EclRatio, x_EclPu, x_EclTemps, x_MachineFonctionnement, x_machinePt, x_GCpu, x_RdegivragePt, x_RdegivrageH As Double
    Dim x_CordonChauffantPortePt, x_CordonChauffantPorteH, x_RubChaufClapetPt, x_RubChaufClapetH, x_CordonChauffanttuyauPt, x_CordonChauffanttuyauH As Double
    Dim x_Ventnb, x_PersoNb, x_Eclnb, x_MursNb, x_ModeCalculApport, x_Service, x_Ouv_Porte As Integer

    ''' <summary>
    ''' Référence de la chambre froide calculée - Exemple: stockage viande, BOF, etc. ...
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Refence As String

    ''' <summary>
    ''' température intérieure de la chambre froide - unité: °C
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property θint As Double
        Get
            θint = x_θint
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la température de la chambre froide n'est pas numérique.")
            Else
                x_θint = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Borne inférieure de l'hygrométrie intérieure de la chambre froide - unité: %
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Hrbas As Double
        Get
            Hrbas = x_hrbas
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de l'hygrométrie de la chambre froide n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de l'hygrométrie de la chambre froide doit être positive.")
            Else
                x_hrbas = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Borne supérieure de l'hygrométrie intérieure de la chambre froide - unité: %
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Hrhaut As Double
        Get
            Hrhaut = x_Hrhaut
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de l'hygrométrie de la chambre froide n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de l'hygrométrie de la chambre froide doit être positive.")
            Else
                x_Hrhaut = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Nombre d'heures de fonctionnement souhaité du groupe de condensation - unité: H
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property GCheure As Double
        Get
            GCheure = x_GCheure
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du nombre d'heures de fonctionnement du groupe de condensation n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du temps de fonctionnement du groupe de condensation doit être positive.")
            Else
                x_GCheure = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Puissance du groupe de condensation - unité: KW
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property GCpu As Double
        Get
            GCpu = x_GCpu
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La puissance du groupe de condensation n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La puissance du groupe de condensation doit être positive.")
            Else
                x_GCpu = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Mode de calcul des apports thermiques: 1=calcul détaillé / 2=par règle du service
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property ModeCalculApport As Integer
        Get
            ModeCalculApport = x_ModeCalculApport
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du Mode de Calcul Apport n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du Mode de Calcul Apport doit être positive.")
            Else
                x_ModeCalculApport = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Service: 1= service Faible / 2 = Service Courant / 3 = Service Fort
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Service As Integer
        Get
            Service = x_Service
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du Service n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du Service doit être positive.")
            Else
                x_Service = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Nombre total de murs - unité: U
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property MursNb As Integer
        Get
            MursNb = x_MursNb
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("Le nombre total de murs n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("Le nombre total de murs doit être positif.")
            Else
                x_MursNb = value
            End If
        End Set
    End Property

#Region "Apports thermiques toutes chambres"
    ''' <summary>
    ''' Ratio de puissance de chaleur dégagée par les ventilateurs des évaporateurs - unité: w/m²
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property VentRatio As Double
        Get
            VentRatio = x_VentRatio
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du ratio puissance/m² ventilateur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du ratio puissance/m² ventilateur doit être positive.")
            Else
                x_VentRatio = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Nombre total de ventilateurs des évaporateurs - unité: U
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Ventnb As Integer
        Get
            Ventnb = x_Ventnb
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du nombre total de ventilateurs n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du nombre total de ventilateurs doit être positive.")
            Else
                x_Ventnb = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Puissance unitaire des ventilateurs des évaporateurs - unité: w/u
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property VentPu As Double
        Get
            VentPu = x_VentPu
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la puissance unitaire des ventilateurs des évaporateurs n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la puissance unitaire des ventilateurs des évaporateurs doit être positive.")
            Else
                x_VentPu = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Nombre total de personnes - unité: U
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property PersoNb As Integer
        Get
            PersoNb = x_PersoNb
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du nombre total de personnes n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du nombre total de personnes doit être positive.")
            Else
                x_PersoNb = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Temps unitaire par personne - unité: h/u
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property PersoTU As Double
        Get
            PersoTU = x_PersoTU
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du temps unitaire par personne n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du temps unitaire par personne doit être positive.")
            Else
                x_PersoTU = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Puissance unitaire des personnes - unité: w/u
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property PersoPu As Double
        Get
            PersoPu = x_PersoPu
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la puissance unitaire des personnes n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la puissance unitaire des personnes doit être positive.")
            Else
                x_PersoPu = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Ratio de puissance de chaleur dégagée par l'éclairage - unité: w/m²
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property EclRatio As Double
        Get
            EclRatio = x_EclRatio
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du ratio puissance/m² de l'éclairage n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du ratio puissance/m² de l'éclairage doit être positive.")
            Else
                x_EclRatio = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Nombre total de luminaires - unité: U
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Eclnb As Integer
        Get
            Eclnb = x_Eclnb
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du nombre total de luminaires n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du nombre total de luminaires doit être positive.")
            Else
                x_Eclnb = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Puissance unitaire des luminaires - unité: w/u
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property EclPu As Double
        Get
            EclPu = x_EclPu
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la puissance unitaire des luminaires n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la puissance unitaire des luminaires doit être positive.")
            Else
                x_EclPu = value
            End If
        End Set
    End Property
    ''' <summary>
    ''' Temps total d'éclairage sur 24h - unité: h
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property EclTemps As Double
        Get
            EclTemps = x_EclTemps
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du temps d'éclairage n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du temps d'éclairage doit être positive.")
            Else
                x_EclTemps = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Puissance totale des machines - unité: w 
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property MachinePt As Double
        Get
            MachinePt = x_MachinePt
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la puissance totale des machines n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la puissance totale des machines doit être positive.")
            Else
                x_MachinePt = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Temps de fonctionnement des machines sur une journée - unité: h
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property MachineFonctionnement As Double
        Get
            MachineFonctionnement = x_MachineFonctionnement
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du temps de fonctionnement des machines n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du temps de fonctionnement des machines doit être positive.")
            Else
                x_MachineFonctionnement = value
            End If
        End Set
    End Property
    ''' <summary>
    ''' Fréquence d'ouverture de portes : 1= Faible / 2 = Normal / 3 = Fort
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Ouv_Porte As Integer
        Get
            Ouv_Porte = x_Ouv_Porte
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la fréquence d'ouverture n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la fréquence d'ouverture de porte doit être positive.")
            Else
                x_Ouv_Porte = value
            End If
        End Set
    End Property
#End Region

#Region "Apports thermiques chambres froides négatives"
    ''' <summary>
    ''' Puissance totale des résistances de dégivrage - unité: w 
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property RdegivragePt As Double
        Get
            RdegivragePt = x_RdegivragePt
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la puissance totale des réistances de dégivrage n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la puissance totale des réistances de dégivrage doit être positive.")
            Else
                x_RdegivragePt = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Temps de fonctionnement des résistance de dégivrage sur une journée - unité: h
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property RdegivrageH As Double
        Get
            RdegivrageH = x_RdegivrageH
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du temps de fonctionnement des réistances de dégivrage n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du temps de fonctionnement des réistances de dégivrage doit être positive.")
            Else
                x_RdegivrageH = value
            End If
        End Set
    End Property
    ''' <summary>
    ''' Puissance totale du cordon chauffant de porte - unité: w 
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property CordonChauffantPortePt As Double
        Get
            CordonChauffantPortePt = x_CordonChauffantPortePt
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la puissance totale du Cordon Chauffant de Porte n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la puissance totale du Cordon Chauffant de Porte doit être positive.")
            Else
                x_CordonChauffantPortePt = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Temps de fonctionnement du cordon chauffant de porte sur une journée - unité: h
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property CordonChauffantPorteH As Double
        Get
            CordonChauffantPorteH = x_CordonChauffantPorteH
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du temps de fonctionnement du Cordon Chauffant de Porte n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du temps de fonctionnement du Cordon Chauffant de Porte doit être positive.")
            Else
                x_CordonChauffantPorteH = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Puissance totale du ruban chauffant du clapet isopression - unité: w 
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property RubChaufClapetPt As Double
        Get
            RubChaufClapetPt = x_RubChaufClapetPt
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la puissance totale du ruban chauffant du clapet isopression n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la puissance totale du ruban chauffant du clapet isopressione doit être positive.")
            Else
                x_RubChaufClapetPt = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Temps de fonctionnement du cordon chauffant de porte sur une journée - unité: h
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property RubChaufClapetH As Double
        Get
            RubChaufClapetH = x_RubChaufClapetH
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du temps de fonctionnement du ruban chauffant du clapet isopression n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du temps de fonctionnement du ruban chauffant du clapet isopression doit être positive.")
            Else
                x_RubChaufClapetH = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Puissance totale du cordon chauffant de tuyauterie - unité: w 
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property CordonChauffanttuyauPt As Double
        Get
            CordonChauffanttuyauPt = x_CordonChauffanttuyauPt
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la puissance totale du Cordon Chauffant de tuyauterie n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la puissance totale du Cordon Chauffant de tuyauterie doit être positive.")
            Else
                x_CordonChauffanttuyauPt = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Temps de fonctionnement du cordon chauffant de tuyauterie sur une journée - unité: h
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property CordonChauffanttuyauH As Double
        Get
            CordonChauffanttuyauH = x_CordonChauffanttuyauH
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur du temps de fonctionnement du Cordon Chauffant de tuyauterie n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur du temps de fonctionnement du Cordon Chauffant de tuyauterie doit être positive.")
            Else
                x_CordonChauffanttuyauH = value
            End If
        End Set
    End Property
#End Region

End Class
