﻿Public Class ClsProduit

    Dim x_θp, x_CpPlus, x_Cp, x_mp, x_mpcal, x_lc, x_dp, x_θpc As Double
    Dim x_ProdUnite As Integer

    ''' <summary>
    ''' Nom du produit = viande, oeuf, lait, ...
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Nom As String

    ''' <summary>
    ''' Température du produit à l'entrée dans la chambre froide - Unité: °C
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property θp As Double
        Get
            θp = x_θp
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la température du produit n'est pas numérique.")
            Else
                x_θp = value
            End If
        End Set
    End Property
    ''' <summary>
    ''' Chaleur massique avant congélation - Unité: KJ/kg.°K
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Cpav As Double
        Get
            Cpav = x_CpPlus
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la Chaleur massique du produit n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la Chaleur massique du produit doit être positive.")
            Else
                x_CpPlus = value
            End If
        End Set
    End Property
    ''' <summary>
    ''' Chaleur massique après congélation - Unité: KJ/kg.°K
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Cpap As Double
        Get
            Cpap = x_Cp
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la Chaleur massique du produit n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la Chaleur massique du produit doit être positive.")
            Else
                x_Cp = value
            End If
        End Set
    End Property
    ''' <summary>
    ''' Quantité de produits introduit par jour dans la chambre froide - Unité: kg ou m3 ou L
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property mp As Double
        Get
            mp = x_mp
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la quantité du produit n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la quantité du produit doit être positive.")
            Else
                x_mp = value
            End If
        End Set
    End Property
    ''' <summary>
    ''' Chaleur latente - Unité: KJ/kg
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property lc As Double
        Get
            lc = x_lc
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la Chaleur latente du produit n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la Chaleur latente du produit doit être positive.")
            Else
                x_lc = value
            End If
        End Set
    End Property
    ''' <summary>
    ''' Densité du produits - Unité: kg 
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property dp As Double
        Get
            dp = x_dp
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la densite du produit n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la densité du produit doit être positive.")
            Else
                x_dp = value
            End If
        End Set
    End Property
    ''' <summary>
    ''' Température de congélation du produit - Unité: °C
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property θpc As Double
        Get
            θpc = x_θpc
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la Température de congélation du produit n'est pas numérique.")
            Else
                x_θpc = value
            End If
        End Set
    End Property
    ''' <summary>
    ''' Unité utilisée pour les mouvements journaliers de matières dans la chambre froide: 0=kg/ 1 =m3/ 2 = Litres
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property ProdUnite As Integer
        Get
            ProdUnite = x_ProdUnite
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur d'index de l'unité n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur d'index de l'unité doit être positive.")
            Else
                x_ProdUnite = value
            End If
        End Set
    End Property
    ''' <summary>
    ''' Quantité de produits introduit par jour dans la chambre froide - Unité: kg 
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property mpcal As Double
        Get
            mpcal = x_mpcal
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur de la quantité du produit n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur de la quantité du produit doit être positive.")
            Else
                x_mpcal = value
            End If
        End Set
    End Property
End Class
